@@ -132,7 +132,9 @@ class PluginContext:
         elif hasattr(rc, "simplify"):
             return rc.simplify()
         else:
-            raise f"Cannot simplify {field_definition}. Perhaps should have used evaluate_raw?"
+            raise AssertionError(
+                f"Cannot simplify {field_definition}. Perhaps should have used evaluate_raw?"
+            )
 
     @property
     def current_filename(self):
